'use client';
import React, { ReactNode, useEffect, useState } from 'react'
import { axiosPrivate } from '../api/axios';
import { useRouter } from 'next/navigation';
import { useAuth } from '../contexts/AuthContext';
import Loader from '../components/Loader';

interface PageProps {
  children: ReactNode;
 }
 
const NotRequireLogin = ({children}: PageProps) => {
  const { token, isTokenLoaded, setUserInfo } = useAuth();
  const router = useRouter()
  const [isAuth, setIsAuth] = useState(true);
  
  const verifyToken = async () => {
    try{
      const response = await axiosPrivate(token!).get('/auth/verify')
      router.push('/dashboard');
      
    }catch(err){
        setIsAuth(false)
    }
  }

  useEffect(() => {
    if(isTokenLoaded){
      if(!token){
        verifyToken();
      }else{
        router.push('/dashboard');
      }
    }
  }, [token, isTokenLoaded]);
  
  return (
    <>
      {isAuth ? <Loader /> : children}
    </>
  )
}

export default NotRequireLogin